<?php
/*-----------------------------------------------------------------------------------------
  Program	: gLight (gLight is the PHP Framework.)
  Author	: Suk-Kyu Yoon, Hyoung-Jun Lee
  License	: MIT license (freeware)
  Homepage	: http://ysksoft.com
-------------------------------------------------------------------------------------------
  Copyright (c) 2009 gLight

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
-------------------------------------------------------------------------------------------*/
class gLight
{
	protected static $check_debug = null;
	private static $page_info = array();

	protected static function getDefine($mode=null)
	{
		if($mode == 'ROOT') {
			return __gLight_ROOT_PATH__;
		} else if($mode == 'MODULE') {
			return __gLight_MODULE_PATH__;
		} else if($mode == 'FILE_DATA') {
			return __gLight_FILE_DATA_PATH__;
		} else if($mode == 'CACHE') {
			return __gLight_CACHE_PATH__;
		} else if($mode == 'TEMPLATE_COMPILE') {
			return __gLight_TEMPLATE_COMPILE_PATH__;
		} else if($mode == 'UPLOAD_FILE') {
			return __gLight_UPLOAD_FILE_PATH__;
		} else if($mode == 'NOT_UPLOAD_FILE_EXT') {
			return __gLight_NOT_UPLOAD_FILE_EXT__;
		} else {
			self::getErrorMsg('Not '.$mode.' Path');
		}
	}

	public static function getModule($module_name)
	{
		if(is_array($module_name)) {
			foreach($module_name as $v) {
				if(!class_exists($v)) {
					self::getInclude($v);
				}
			}
		} else {
			if(!class_exists($module_name)) {
				self::getInclude($module_name);
			}
		}
	}

	private static function getInclude($module_name)
	{
		$module_file = self::getDefine('MODULE').'/'.$module_name.'/class.gLight_'.$module_name.'.php';
		if(file_exists($module_file)) {
			include_once $module_file;
		} else {
			self::getErrorMsg('Not Found gLight Module');
		}
	}

	public static function setDebug($ip)
	{
		if(strpos($ip, $_SERVER['REMOTE_ADDR']) !== false) {
			self::$check_debug = true;
		} else {
			self::$check_debug = false;
		}
	}

	protected static function getDebug()
	{
		return self::$check_debug;
	}

	protected static function getErrorMsg($error_msg, $mode=null)
	{
		if(self::getDebug() == true) {
			if($mode == 'return') {
				return 'gLight Error Msg => '.$error_msg;
			} else {
				echo '<pre>';
				echo '<b style="color:red">gLight Error Msg => </b><b>'.$error_msg.'</b>';
				echo '</pre>';
				exit;
			}
		}
	}

	public static function setMakeDir()
	{
		if(!is_dir(self::getDefine('FILE_DATA'))) mkdir(self::getDefine('FILE_DATA'), 0777);
		if(!is_dir(self::getDefine('CACHE'))) mkdir(self::getDefine('CACHE'), 0777);
		if(!is_dir(self::getDefine('TEMPLATE_COMPILE'))) mkdir(self::getDefine('TEMPLATE_COMPILE'), 0777);
		if(!is_dir(self::getDefine('UPLOAD_FILE'))) mkdir(self::getDefine('UPLOAD_FILE'), 0777);
	}

	protected static function getCallMethod($method_name, $params=array())
	{
		return call_user_func_array($method_name, $params);
	}

	public static function getJS($mode, $msg=null)
	{
		$script = '<script type="text/javascript">';
		$script_alert_msg = ($msg) ? 'alert("'.$msg.'");' : '';
		$script_history_back = 'history.back();';

		if($mode == 'alert_back') {
			$script .= $script_alert_msg;
			$script .= $script_history_back;
		}

		$script .= '</script>';
		echo $script;
		exit;
	}

	public static function getPageInfo($mode)
	{
		if(self::getDebug() == true) {
			if($mode == 'start') {
				self::$page_info['memory_total'] = str_replace('M', '000000', ini_get('memory_limit'));
				self::$page_info['memory_start'] = memory_get_usage();
				self::$page_info['page_loading_start_time'] = explode(' ',microtime());
			} else if($mode == 'end') {
				self::$page_info['page_loading_end_time'] = explode(' ',microtime());
				self::$page_info['memory_end'] = memory_get_usage();
				echo '
				<h3 style="color:blue">gLight Page Information</h3>
				<table border="1" width="600" cellpadding="0" cellspacing="0">
				<tr>
					<td width="200" bgcolor="#EFEFEF"><b>&nbsp;Page Loading Time</b></td>
					<td>&nbsp;'.substr((self::$page_info['page_loading_end_time'][1]-self::$page_info['page_loading_start_time'][1])+(self::$page_info['page_loading_end_time'][0]-self::$page_info['page_loading_start_time'][0]),0,6).' sec</td>
				</tr>
				<tr>
					<td bgcolor="#EFEFEF"><b>&nbsp;Total Memory</b></td>
					<td>&nbsp;'.number_format(self::$page_info['memory_total']).' Byte</td>
				</tr>
				<tr>
					<td bgcolor="#EFEFEF"><b>&nbsp;Before Memory</b></td>
					<td>&nbsp;'.number_format(self::$page_info['memory_start']).' Byte</td>
				</tr>
				<tr>
					<td bgcolor="#EFEFEF"><b>&nbsp;After Memory</b></td>
					<td>&nbsp;'.number_format(self::$page_info['memory_end']).' Byte</td>
				</tr>
				<tr>
					<td bgcolor="#EFEFEF"><b>&nbsp;Use Memory</b></td>
					<td>&nbsp;'.number_format(self::$page_info['memory_end']-self::$page_info['memory_start']).' Byte</td>
				</tr>
				<tr>
					<td bgcolor="#EFEFEF"><b>&nbsp;Remnant Memory</b></td>
					<td>&nbsp;'.number_format(self::$page_info['memory_total']-(self::$page_info['memory_end']-self::$page_info['memory_start'])).' Byte</td>
				</tr>
				</table>
				';
			}
		}
	}
}
?>