<?php
/*-----------------------------------------------------------------------------------------
  Program	: gLight (gLight is the PHP Framework.)
  Author	: Suk-Kyu Yoon, Hyoung-Jun Lee
  License	: MIT license (freeware)
  Homepage	: http://ysksoft.com
-------------------------------------------------------------------------------------------
  Copyright (c) 2009 gLight

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
-------------------------------------------------------------------------------------------*/
class gLight_DB extends gLight
{
	protected static $db_host = null;
	protected static $db_user = null;
	protected static $db_pass = null;
	protected static $db_name = null;
	protected static $db_port = null;

	private static $db_driver = null;
	private static $check_db_debug = false;

	public static function init($select_db, $db_host, $db_user, $db_pass, $db_name, $db_port=null, $check_db_debug=false)
	{
		self::$db_host = $db_host;
		self::$db_user = $db_user;
		self::$db_pass = $db_pass;
		self::$db_name = $db_name;
		self::$db_port = $db_port;
		self::$check_db_debug = $check_db_debug;
		self::$db_driver = 'gLight_DB_'.$select_db;

		$db_driver_file = parent::getDefine('MODULE').'/DB/class.'.self::$db_driver.'.php';
		if(file_exists($db_driver_file)) {
			if(!class_exists(self::$db_driver)) {
				include_once $db_driver_file;
			}
		} else {
			parent::getErrorMsg('Not Found gLight DB Driver');
		}

		parent::getCallMethod(self::$db_driver.'::setConnect');
	}

	protected static function getDBConnectInfo()
	{
		return array('db_host'=>self::$db_host, 'db_user'=>self::$db_user, 'db_pass'=>self::$db_pass, 'db_name'=>self::$db_name);
	}

	private static function getDBErrorMsg($sql, $error_msg=null, $mode=null)
	{
		if(parent::getDebug() == true) {
			if($mode == 'error') {
				$color = 'red';
			} else {
				$color = 'blue';
			}
			echo '<pre>';
			if($error_msg && $mode == 'error') {
				echo '<b style="color:'.$color.'">gLight DB Sql => </b><b>'.$sql.'</b><br>';
				echo '<b style="color:red">gLight DB Error Msg => </b><b>'.$error_msg.'</b><br><br>';
				echo '</pre>';
				exit;
			} else {
				echo '<b style="color:'.$color.'">gLight DB Sql => </b><b>'.$sql.'</b><br>';
			}
			echo '</pre>';
		}
	}

	private static function setDBCache($sql, $mode, &$array_data=array())
	{
		$md5_key = md5($sql);
		$cache_file = 'db_cache_'.$md5_key.'.php';
		$result_cache_file = parent::getDefine('CACHE').'/'.$cache_file;

		if(!file_exists($result_cache_file)) {
			if($mode == 'add') {
				$cache_value = '<?php'."\n";
				$cache_value .= '$cache_result = array();';
				foreach($array_data as $array_key=>$array_data_value) {
					if(is_array($array_data_value)) {
						foreach($array_data_value as $k=>$v) {
							if(is_int($k)) {
								$cache_value .= '$cache_result['.$array_key.']['.$k.'] = \''.$v.'\';';
							} else {
								$cache_value .= '$cache_result['.$array_key.'][\''.$k.'\'] = \''.$v.'\';';
							}
						}
					} else {
						if(is_int($array_key)) {
							$cache_value .= '$cache_result['.$array_key.'] = \''.$array_data_value.'\';';
						} else {
							$cache_value .= '$cache_result['.$array_key.'] = \''.$array_data_value.'\';';
						}
					}
				}
				$cache_value .= "\n".'?>';

				$fp = fopen($result_cache_file, 'w');
				fwrite($fp, $cache_value);
				fclose($fp);
			} else if($mode == 'load' || $mode == 'del') {
				return array(false);
			}
		} else {
			if($mode == 'del') {
				if(file_Exists($result_cache_file)) unlink($result_cache_file);
				return array(false);
			}
			echo "<!-- DB Cache : ".$md5_key.' / '.date('Y-m-d H:i:s',filemtime($result_cache_file))." -->\n";
		}
		include_once $result_cache_file;
		return array(true, $cache_result);
	}

	public static function getQuery($sql, $check_db_debug=false, $cache=false)
	{
		if($check_db_debug == true || self::$check_db_debug == true) self::getDBErrorMsg($sql);
		$query = parent::getCallMethod(self::$db_driver.'::getQuery', array($sql));
		if($query[0] == false) self::getDBErrorMsg($sql, $query[1], 'error');
		return $query[0];
	}

	public static function getSelect($table, $field=null, $where=null, $check_db_debug=false, $cache=false)
	{
		if($table && $field && $field != 1) {
			$where = ($where) ? ' WHERE '.$where : '';
			$sql = 'SELECT '.$field.' FROM '.$table.$where;
		} else {
			$sql = $table;
			$check_db_debug = $field;
			$cache = $where;
		}
		if($cache == true) {
			$result_db_cache = self::setDBCache($sql, 'load');
			if($result_db_cache[0] == true) return $result_db_cache[1];
		} else if($cache == false) {
			self::setDBCache($sql, 'del');
		}
		$query = self::getQuery($sql, $check_db_debug);
		$result	= array();
		while($row = parent::getCallMethod(self::$db_driver.'::getSelectFetchArray', array($query))) {
			$result[] = $row;
		}
		if($cache == true) self::setDBCache($sql, 'add', $result);
		return $result;
	}

	public static function getSelectOnce($table, $field=null, $where=null, $check_db_debug=false, $cache=false)
	{
		if($table && $field && $field != 1) {
			$where = ($where) ? ' WHERE '.$where : '';
			$sql = 'SELECT '.$field.' FROM '.$table.$where;
		} else {
			$sql = $table;
			$check_db_debug = $field;
			$cache = $where;
		}
		if($cache == true) {
			$result_db_cache = self::setDBCache($sql, 'load');
			if($result_db_cache[0] == true) return $result_db_cache[1];
		} else if($cache == false) {
			self::setDBCache($sql, 'del');
		}
		$query = self::getQuery($sql, $check_db_debug);
		$result	= array();
		$result = parent::getCallMethod(self::$db_driver.'::getSelectFetchArray', array($query));
		if($cache == true) self::setDBCache($sql, 'add', $result);
		return $result;
	}
}
?>