<?php
/*-----------------------------------------------------------------------------------------
  Program	: gLight (gLight is the PHP Framework.)
  Author	: Suk-Kyu Yoon, Hyoung-Jun Lee
  License	: MIT license (freeware)
  Homepage	: http://ysksoft.com
-------------------------------------------------------------------------------------------
  Copyright (c) 2009 gLight

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
-------------------------------------------------------------------------------------------*/
class gLight_File extends gLight
{
	public static function cache($key, $value, $time=0)
	{
		if(!$value) parent::getErrorMsg('Not Cache Value');

		$md5_key = md5($key);
		$cache_file = 'file_cache_'.$md5_key.'.php';
		$result_cache_file = parent::getDefine('CACHE').'/'.$cache_file;
		$check_create = false;

		if(!file_exists($result_cache_file)) {
			$check_create = true;
		} else {
			if(is_int($time) && $time > 0) {
				$cache_file_time = filemtime($result_cache_file);
				$config_time = $cache_file_time+$time;
				$now_time = mktime();
				if($config_time <= $now_time) $check_create = true;
			}
		}

		if(is_array($value)) {
			if($check_create == true) {
				$cache_value = '<?php'."\n";
				$cache_value .= '$cache_result = array();';
				foreach($value as $array_key=>$array_data_value) {
					if(is_array($array_data_value)) {
						foreach($array_data_value as $k=>$v) {
							if(is_int($k)) {
								$cache_value .= '$cache_result['.$array_key.']['.$k.'] = \''.$v.'\';';
							} else {
								$cache_value .= '$cache_result['.$array_key.'][\''.$k.'\'] = \''.$v.'\';';
							}
						}
					} else {
						if(is_int($array_key)) {
							$cache_value .= '$cache_result['.$array_key.'] = \''.$array_data_value.'\';';
						} else {
							$cache_value .= '$cache_result[\''.$array_key.'\'] = \''.$array_data_value.'\';';
						}
					}
				}
				$cache_value .= "\n".'?>';
				self::setWrite($result_cache_file, $cache_value);
			}
			include_once $result_cache_file;
		} else {
			if($check_create == true) {
				self::setWrite($result_cache_file, $value);
			}
			$cache_result = self::getRead($result_cache_file);
		}
		return $cache_result;
	}

	public static function setWrite($file, &$value, $mode='w')
	{
		$fp = fopen($file, $mode) or die(parent::getErrorMsg('Not Make File'));
		fwrite($fp, $value);
		fclose($fp);
	}

	public static function getRead($file)
	{
		$fp = fopen($file, 'r') or die(parent::getErrorMsg('Not Read File'));
		$result = fread($fp, filesize($file));
		fclose($fp);
		return $result;
	}

	public static function setDelete($path, $mode='file')
	{
		if($mode == 'dir') {
			if(is_dir($path)) {
				rmdir($path);
			} else {
				parent::getErrorMsg('Not Delete Directory');
			}
		} else if($mode == 'file') {
			if(file_exists($path)) {
				unlink($path);
			} else {
				parent::getErrorMsg('Not Delete File');
			}
		} else {
			parent::getErrorMsg('Not Delete Mode');
		}
	}

	public static function setMkdir($upload_path, $permission='0777')
	{
		if(!is_dir($upload_path)) {
			$ex_upload_path = explode('/', $upload_path);
			$temp_dir = '';
			foreach($ex_upload_path as $v) {
				$temp_dir .= $v.'/';
				if(!is_dir($temp_dir)) {
					mkdir($temp_dir, $permission);
				}
			}
		}
		return $upload_path;
	}

	public static function setUpload($upload_file, $upload_path=null)
	{
		if(!$upload_file['tmp_name'] || !$upload_file['name'] || !$upload_file['size']) parent::getErrorMsg('Not $_FILES');
		$file_ext = substr($upload_file['name'], strrpos($upload_file['name'], '.'));
		$not_file_ext = explode('||', parent::getDefine('NOT_UPLOAD_FILE_EXT'));
		if(in_array($file_ext, $not_file_ext)) {
			parent::getJS('alert_back', parent::getErrorMsg('Not Upload File Ext', 'return'));
		}

		$upload_path = ($upload_path) ? self::setMkdir($upload_path) : parent::getDefine('UPLOAD_FILE');
		$upload_path = $upload_path.'/'.date('Y').'/'.date('m').'/'.date('d');
		$upload_path = str_replace('//', '/', $upload_path);
		$upload_path = self::setMkdir($upload_path);

		switch($file_ext) {
			case '.jpg':
			case '.jpeg':
			case '.gif':
			case '.png':
			case '.bmp':
				$file_name_rlt = md5(mt_rand().microtime()).$file_ext;
				break;
			default:
				$file_name_rlt = $upload_file['name'].'____'.md5(mt_rand().microtime()).$file_ext;
				break;
		}

		$result = array();
		if(move_uploaded_file($upload_file['tmp_name'], $upload_path.'/'.$file_name_rlt)) {
			$temp_file_upload_path = str_replace($_SERVER['DOCUMENT_ROOT'] ,'', $upload_path);
			$result['upload_file_name'] = $upload_file['name'];
			$result['upload_file_path'] = $temp_file_upload_path.'/'.$file_name_rlt;
			$result['upload_file_size'] = $upload_file['size'];
			$result['upload_file_time'] = filemtime($_SERVER['DOCUMENT_ROOT'].'/'.$temp_file_upload_path.'/'.$file_name_rlt);
			return $result;
		} else {
			self::setDelete($upload_path, 'dir');
			parent::getJS('alert_back', parent::getErrorMsg('Upload Directory Check Permission', 'return'));
		}
	}

	public static function getDownload($download_file_path, $download_file_name=null)
	{
		if(!file_exists($_SERVER['DOCUMENT_ROOT'].$download_file_path)) parent::getJS('alert_back', parent::getErrorMsg('Not File Download', 'return'));
		if($download_file_name == null) {
			$download_file_name = substr($download_file_path, 0, strrpos($download_file_path, '____'));
			$download_file_name = substr($download_file_name, strrpos($download_file_name, '/')+1);
		}
		@header('Content-type: file/unknown');
		@Header('Content-Length: '.filesize($_SERVER['DOCUMENT_ROOT'].$download_file_path));
		@header('Content-Disposition: attachment; filename='.$download_file_name);
		@header('Content-Transfer-Encoding: binary');
		@header('Pragma: no-cache');
		@header('Expires: 0');
		$fp = fopen($_SERVER['DOCUMENT_ROOT'].$download_file_path, 'r');
		if (!fpassthru($fp)) {
			fclose($fp);
			clearstatcache($fp);
		}
	}
}
?>