<?php
/*-----------------------------------------------------------------------------------------
  Program	: gLight (gLight is the PHP Framework.)
  Author	: Suk-Kyu Yoon, Hyoung-Jun Lee
  License	: MIT license (freeware)
  Homepage	: http://ysksoft.com
-------------------------------------------------------------------------------------------
  Copyright (c) 2009 gLight

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
-------------------------------------------------------------------------------------------*/
class gLight_Image extends gLight
{
	public static function setResampled($file_name, $width, $height)
	{
		if(empty($file_name) === false || file_exists($file_name) === false)	return false;
		if(empty($width) === false && empty($height) === false)	return false;

		$image_info = self::getImageInfo($file_name);
		$image_type = self::getImageType($file_name);

		switch ($image_type) {
			case 'gif' :
				if(imagetypes() & IMG_GIF) {
					$image_device = imagecreatefromgif($file_name);
				} else {
					return false;
				}
				break;
			case 'jpg' :
				if(imagetypes() & IMG_JPG) {
					$image_device = imagecreatefromjpeg($file_name);
				} else {
					return false;
				}
				break;
			case 'png' :
				if((imagetypes() & IMG_PNG) && function_exists('imagecreatefrompng') === true) {
					$image_device = imagecreatefrompng($file_name);
				} else {
					return false;
				}
				break;
			case 'wbmp' :
				if(imagetypes() & IMG_WBMP) {
					$image_device = imagecreatefromwbmp($file_name);
				} else {
					return false;
				}
				break;
			case 'xpm' :
				if(imagetypes() & IMG_XPM) {
					$image_device = imagecreatefromxpm($file_name);
				} else {
					return false;
				}
				break;
			default :
				return false;
				break;
		}

		if($image_type == 'gif') {
			$image = imagecreate($width, $height);
		} else {
			$image = imagecreatetruecolor($width, $height);
		}

		$rgb_code = self::getRGBCode('FFFFFF');
		$tmp_img = imagecolorallocate($image, $rgb_code['R'], $rgb_code['G'], $rgb_code['B']);
		imagefilledrectangle($image, 0, 0, $width, $height, $tmp_img);
		imagecopyresampled($image, $image_device, 0, 0, 0, 0, $width, $height, imagesx($image_device), imagesy($image_device));
		imagedestroy($image_device);
		self::setThumbnail($file_name, $image);
	}

	public static function setThumbnail($file_name, $image)
	{
		if(empty($file_name) === false || file_exists($file_name) === false)	return false;
		if(empty($image) === false)	return false;

		imageinterlace($image);
		switch (self::getImageType($file_name)) {
			case 'gif' :
				imagegif($image, $file_name);
				break;
			case 'png' :
				imagepng($image, $file_name);
				break;
			case 'wbmp' :
				imagewbmp($image, $file_name);
				break;
			case 'jpg' :
			default :
				imagejpeg($image, $file_name, 100);
				break;
		}

		return true;
	}

	private static function getImageType($file_name)
	{
		if(file_exists($file_name) === true) {
			if(function_exists('exif_imagetype') === true) {
				$image_type = exif_imagetype($file_name);
			} else {
				$image_info = self::getImageInfo($file_name);
				$image_type = $image_info[2];
			}

			switch($image_type) {
				case IMAGETYPE_GIF :
					$extension = 'gif';
					break;
				case IMAGETYPE_JPEG :
					$extension = 'jpg';
					break;
				case IMAGETYPE_PNG :
					$extension = 'png';
					break;
				case IMAGETYPE_SWF :
					$extension = 'swf';
					break;
				case IMAGETYPE_PSD :
					$extension = 'psd';
					break;
				case IMAGETYPE_BMP :
					$extension = 'bmp';
					break;
				case IMAGETYPE_TIFF_II :
				case IMAGETYPE_TIFF_MM :
					$extension = 'tiff';
					break;
				case IMAGETYPE_JPC :
					$extension = 'jpc';
					break;
				case IMAGETYPE_JP2 :
					$extension = 'jp2';
					break;
				case IMAGETYPE_JPX :
					$extension = 'jpx';
					break;
				case IMAGETYPE_JB2 :
					$extension = 'jb2';
					break;
				case IMAGETYPE_SWC :
					$extension = 'swc';
					break;
				case IMAGETYPE_IFF :
					$extension = 'aiff';
					break;
				case IMAGETYPE_WBMP :
					$extension = 'wbmp';
					break;
				case IMAGETYPE_XBM :
					$extension = 'xbm';
					break;
				default :
					$extension = false;
					break;
			}
		} else {
			$extension = false;
		}

		return $extension;
	}

	private static function getImageInfo($file_name)
	{
		if(file_exists($file_name) === true) {
			$image_info = getimagesize($file_name);
			return $image_info;
		} else {
			return false;
		}
	}

	private static function getRGBCode($color_code)
	{
		$hex_code = hexdec($color_code);
		$result['R'] = 0xFF & ($hex_code >> 0x10);
		$result['G'] = 0xFF & ($hex_code >> 0x8);
		$result['B'] = 0xFF & $hex_code;
		return $result;
	}
}
?>